@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Embedded message %s" : "포함된 메시지 %s",
     "Important mail" : "중요 메일",
+    "Set up an account" : "계정 설정",
     "Unread mail" : "읽지 않은 메일",
     "Important" : "중요",
     "Work" : "직장",
@@ -59,6 +60,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
     "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
     "Show keyboard shortcuts" : "키보드 단축키 표시",
+    "Newest" : "최신순",
+    "Oldest" : "과거순",
     "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
     "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
@@ -97,7 +100,6 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
     "Choose a file to share as a link" : "공유할 링크 파일을 선택하세요.",
     "Confirm" : "확인",
-    "Set up an account" : "계정 설정",
     "Plain text" : "평문",
     "Rich text" : "서식 있는 텍스트",
     "No messages" : "메시지가 없음",
@@ -167,6 +169,7 @@ OC.L10N.register(
     "Copy to clipboard" : "클립보드로 복사",
     "Add" : "추가",
     "Close" : "닫기",
+    "Body" : "몸통",
     "Select recipients" : "받는이 선택",
     "Select CC recipients" : "CC 받는이 선택",
     "Select BCC recipients" : "BCC 받는이 선택",
@@ -221,6 +224,8 @@ OC.L10N.register(
     "Account connected" : "계정 연결됨",
     "Connect your mail account" : "메일 계정에 연결",
     "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
+    "Tomorrow – {timeLocale}" : "내일 – {timeLocale}",
+    "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
     "All" : "모두",
     "Drafts" : "임시 보관함",
     "Favorites" : "즐겨찾기",
