@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Įterptas laiškas %s",
     "Important mail" : "Svarbūs laiškai",
+    "No message found yet" : "Kol kas nerasta jokių el. laiškų",
+    "Set up an account" : "Nusistatyti paskyrą",
     "Unread mail" : "Neskaitytas paštas",
     "Important" : "Svarbūs",
     "Work" : "Darbas",
@@ -73,6 +75,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
     "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Newest" : "Naujausios",
+    "Oldest" : "Seniausios",
     "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
     "Could not update preference" : "Nepavyko atnaujinti nuostatos",
@@ -117,8 +121,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
     "Confirm" : "Patvirtinti",
-    "No message found yet" : "Kol kas nerasta jokių el. laiškų",
-    "Set up an account" : "Nusistatyti paskyrą",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
     "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
@@ -139,6 +141,10 @@ OC.L10N.register(
     "Create task" : "Sukurti užduotį",
     "Download message" : "Atsisiųsti laišką",
     "No subject" : "Be temos",
+    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
+    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
+    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
+    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
     "Could not delete message" : "Nepavyko ištrinti laiško",
     "Could not archive message" : "Nepavyko archyvuoti laiško",
     "Forward" : "Persiųsti",
@@ -171,13 +177,13 @@ OC.L10N.register(
     "Reply to sender only" : "Atsakyti tik siuntėjui",
     "Move message" : "Perkelti laišką",
     "Forward message as attachment" : "Persiųsti laišką kaip priedą",
-    "Message source" : "Pirminis laiško kodas",
     "Message body" : "Pagrindinė laiško dalis",
     "Import into calendar" : "Importuoti į kalendorių",
     "Download attachment" : "Atsisiųsti priedą",
     "Save to Files" : "Įrašyti į Failus",
     "Unnamed" : "Be pavadinimo",
     "Embedded message" : "Įterptas laiškas",
+    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
     "View fewer attachments" : "Rodyti mažiau priedų",
     "Save all to Files" : "Įrašyti visus į Failus",
@@ -257,19 +263,22 @@ OC.L10N.register(
     "Disabled" : "Išjungta",
     "Enabled" : "Įjungta",
     "Custom" : "Tinkinti",
+    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
     "Signature …" : "Parašas…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
+    "Delete tag" : "Ištrinti žymę",
+    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymės.",
     "Add tag" : "Pridėti žymę",
     "Saving tag …" : "Įrašoma žymė…",
     "Tag already exists" : "Žymė jau yra",
     "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymės.",
-    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymės.",
     "Not found" : "Nerasta",
     "Unsubscribe" : "Atsisakyti prenumeratos",
     "Mark as unread" : "Žymėti kaip neskaitytą",
     "Mark as read" : "Žymėti kaip skaitytą",
     "Delete message" : "Ištrinti laišką",
+    "Message source" : "Pirminis laiško kodas",
     "Remove" : "Šalinti",
     "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
@@ -330,6 +339,7 @@ OC.L10N.register(
     "You can close this window" : "Galite užverti šį langą",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
     "To add a mail account, please contact your administrator." : "Norėdami pridėti pašto paskyrą, susisiekite su savo administratoriumi.",
+    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "All" : "Visos",
     "Drafts" : "Juodraščiai",
     "Favorites" : "Mėgstami",
