@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Inbäddat meddelande %s",
     "Important mail" : "Viktig e-post",
+    "No message found yet" : "Inget meddelande har ännu hittats",
+    "Set up an account" : "Skapa ett konto",
     "Unread mail" : "Oläst e-post",
     "Important" : "Viktigt",
     "Work" : "Arbete",
@@ -103,8 +105,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Välj en fil att dela som länk",
     "_{count} attachment_::_{count} attachments_" : ["{count} bilaga","{count} bilagor"],
     "Confirm" : "Bekräfta",
-    "No message found yet" : "Inget meddelande har ännu hittats",
-    "Set up an account" : "Skapa ett konto",
     "Plain text" : "Oformaterad text",
     "Rich text" : "Formaterad text",
     "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
@@ -172,13 +172,13 @@ OC.L10N.register(
     "Move message" : "Flytta meddelande",
     "Forward message as attachment" : "Vidarebefordra medelande som bilaga",
     "View source" : "Visa källa",
-    "Message source" : "Meddelandekälla",
     "Message body" : "Meddelandetext",
     "Import into calendar" : "Importera till kalender",
     "Download attachment" : "Hämta bilaga",
     "Save to Files" : "Spara till filer",
     "Unnamed" : "Namnlös",
     "Embedded message" : "Inbäddat meddelande",
+    "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
     "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
     "Save all to Files" : "Spara alla i filer",
     "Download Zip" : "Ladda ner arkiv",
@@ -228,6 +228,7 @@ OC.L10N.register(
     "Send anyway" : "Skicka ändå",
     "Edit message" : "Redigera meddelande",
     "Draft" : "Utkast",
+    "First day" : "Första dagen",
     "Message" : "Meddelande",
     "Oh Snap!" : "Hoppsan!",
     "Could not open outbox" : "Kunde inte öppna utkorgen",
@@ -241,7 +242,9 @@ OC.L10N.register(
     "Search in mailbox" : "Sök i brevlådan",
     "Close" : "Stäng",
     "Search parameters" : "Sökparametrar",
-    "Search term" : "Sökterm",
+    "Body" : "Textyta",
+    "Pick a start date" : "Välj ett startdatum",
+    "Pick an end date" : "Välj ett slutdatum",
     "Tags" : "Taggar",
     "Select tags" : "Välj taggar",
     "Clear" : "Rensa",
@@ -251,16 +254,17 @@ OC.L10N.register(
     "Enabled" : "Aktiverad",
     "IMAP Credentials" : "IMAP-inställningar",
     "Custom" : "Anpassad",
+    "This weekend – {timeLocale}" : "Den här helgen – {timeLocale}",
     "Signature …" : "Signatur …",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
+    "Delete tag" : "Radera tagg",
+    "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
     "Add default tags" : "Lägg till standardtaggar",
-    "Rename tag" : "Byt namn på tagg",
     "Add tag" : "Lägg till tagg",
     "Saving tag …" : "Sparar tagg …",
     "Tag already exists" : "Taggen finns redan",
     "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
-    "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
     "Not found" : "Hittades inte",
     "Could not load your message thread" : "Det gick inte att ladda meddelandetråden",
     "Unsubscribe" : "Avsluta prenumeration",
@@ -268,6 +272,7 @@ OC.L10N.register(
     "Mark as read" : "Markera som läst",
     "Archive message" : "Arkivera meddelandet",
     "Delete message" : "Radera meddelande",
+    "Message source" : "Meddelandekälla",
     "Remove" : "Ta bort",
     "No senders are trusted at the moment." : "Inga avsändare är betrodda för tillfället.",
     "individual" : "individ",
@@ -314,6 +319,8 @@ OC.L10N.register(
     "Archive" : "Arkivera",
     "Account connected" : "Konto anslutet",
     "Connect your mail account" : "Anslut ditt e-postkonto",
+    "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
+    "Later today – {timeLocale}" : "Senare idag – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
     "All" : "Alla",
     "Drafts" : "Utkast",
