@@ -66,10 +66,12 @@ use OCA\Mail\Listener\MessageKnownSinceListener;
 use OCA\Mail\Listener\MoveJunkListener;
 use OCA\Mail\Listener\NewMessageClassificationListener;
 use OCA\Mail\Listener\OauthTokenRefreshListener;
+use OCA\Mail\Listener\OutOfOfficeListener;
 use OCA\Mail\Listener\SaveSentMessageListener;
 use OCA\Mail\Listener\SpamReportListener;
 use OCA\Mail\Listener\UserDeletedListener;
 use OCA\Mail\Notification\Notifier;
+use OCA\Mail\Search\FilteringProvider;
 use OCA\Mail\Search\Provider;
 use OCA\Mail\Service\Attachment\AttachmentService;
 use OCA\Mail\Service\AvatarService;
@@ -86,9 +88,16 @@ use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
 use OCP\Dashboard\IAPIWidgetV2;
 use OCP\IServerContainer;
+use OCP\Search\IFilteringProvider;
+use OCP\User\Events\OutOfOfficeChangedEvent;
+use OCP\User\Events\OutOfOfficeClearedEvent;
+use OCP\User\Events\OutOfOfficeEndedEvent;
+use OCP\User\Events\OutOfOfficeScheduledEvent;
+use OCP\User\Events\OutOfOfficeStartedEvent;
 use OCP\User\Events\UserDeletedEvent;
 use OCP\Util;
 use Psr\Container\ContainerInterface;
+use function interface_exists;
 
 include_once __DIR__ . '/../../vendor/autoload.php';
 
@@ -139,6 +148,20 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(SynchronizationEvent::class, AccountSynchronizedThreadUpdaterListener::class);
 		$context->registerEventListener(UserDeletedEvent::class, UserDeletedListener::class);
 
+		// TODO: drop condition if nextcloud < 28 is not supported anymore
+		if (class_exists(OutOfOfficeStartedEvent::class)
+			&& class_exists(OutOfOfficeEndedEvent::class)
+			&& class_exists(OutOfOfficeChangedEvent::class)
+			&& class_exists(OutOfOfficeClearedEvent::class)
+			&& class_exists(OutOfOfficeScheduledEvent::class)
+		) {
+			$context->registerEventListener(OutOfOfficeStartedEvent::class, OutOfOfficeListener::class);
+			$context->registerEventListener(OutOfOfficeEndedEvent::class, OutOfOfficeListener::class);
+			$context->registerEventListener(OutOfOfficeChangedEvent::class, OutOfOfficeListener::class);
+			$context->registerEventListener(OutOfOfficeClearedEvent::class, OutOfOfficeListener::class);
+			$context->registerEventListener(OutOfOfficeScheduledEvent::class, OutOfOfficeListener::class);
+		}
+
 		$context->registerMiddleWare(ErrorMiddleware::class);
 		$context->registerMiddleWare(ProvisioningMiddleware::class);
 
@@ -150,7 +173,11 @@ class Application extends App implements IBootstrap {
 			$context->registerDashboardWidget(UnreadMailWidget::class);
 		}
 
-		$context->registerSearchProvider(Provider::class);
+		if (interface_exists(IFilteringProvider::class)) {
+			$context->registerSearchProvider(FilteringProvider::class);
+		} else {
+			$context->registerSearchProvider(Provider::class);
+		}
 
 		$context->registerNotifierService(Notifier::class);
 
