@@ -94,7 +94,6 @@ class AliasMapper extends QBMapper {
 
 	/**
 	 * @param int $accountId the account whose aliases will be deleted
-	 * @param string $currentUserId the user that is currently logged in
 	 *
 	 * @return void
 	 */
@@ -105,7 +104,7 @@ class AliasMapper extends QBMapper {
 			->delete($this->getTableName())
 			->where($qb->expr()->eq('account_id', $qb->createNamedParameter($accountId)));
 
-		$query->execute();
+		$query->executeStatement();
 	}
 
 	/**
@@ -128,7 +127,7 @@ class AliasMapper extends QBMapper {
 				$qb->expr()->isNotNull('provisioning_id')
 			);
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 	public function deleteOrphans(): void {
@@ -137,7 +136,7 @@ class AliasMapper extends QBMapper {
 			->from($this->getTableName(), 'a')
 			->leftJoin('a', 'mail_accounts', 'ac', $qb1->expr()->eq('a.account_id', 'ac.id'))
 			->where($qb1->expr()->isNull('ac.id'));
-		$result = $idsQuery->execute();
+		$result = $idsQuery->executeQuery();
 		$ids = array_map(static function (array $row) {
 			return (int)$row['id'];
 		}, $result->fetchAll());
@@ -150,7 +149,7 @@ class AliasMapper extends QBMapper {
 			);
 		foreach (array_chunk($ids, 1000) as $chunk) {
 			$qb2->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
-			$qb2->execute();
+			$qb2->executeStatement();
 		}
 	}
 }
