@@ -29,6 +29,7 @@ namespace OCA\Mail\Db;
 use OCA\Mail\Account;
 use OCA\Mail\Address;
 use OCA\Mail\AddressList;
+use OCA\Mail\Contracts\IMailSearch;
 use OCA\Mail\IMAP\Threading\DatabaseMessage;
 use OCA\Mail\Service\Search\Flag;
 use OCA\Mail\Service\Search\FlagExpression;
@@ -700,7 +701,7 @@ class MessageMapper extends QBMapper {
 	 *
 	 * @return int[]
 	 */
-	public function findIdsByQuery(Mailbox $mailbox, SearchQuery $query, ?int $limit, array $uids = null): array {
+	public function findIdsByQuery(Mailbox $mailbox, SearchQuery $query, string $sortOrder, ?int $limit, array $uids = null): array {
 		$qb = $this->db->getQueryBuilder();
 
 		if ($this->needDistinct($query)) {
@@ -751,59 +752,77 @@ class MessageMapper extends QBMapper {
 					...array_map(function (string $label) use ($qb) {
 						return $qb->expr()->iLike('r0.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getFrom()),
-				)
+				),
+				$qb->expr()->eq('r0.type', $qb->createNamedParameter(Recipient::TYPE_FROM, IQueryBuilder::PARAM_INT)),
 			);
 		}
 		if (!empty($query->getTo())) {
 			$select->andWhere(
 				$qb->expr()->orX(
 					...array_map(function (string $email) use ($qb) {
-						return $qb->expr()->iLike('r0.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r1.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getTo()),
 					...array_map(function (string $label) use ($qb) {
-						return $qb->expr()->iLike('r0.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r1.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getTo()),
-				)
+				),
+				$qb->expr()->eq('r1.type', $qb->createNamedParameter(Recipient::TYPE_TO, IQueryBuilder::PARAM_INT)),
 			);
 		}
 		if (!empty($query->getCc())) {
 			$select->andWhere(
 				$qb->expr()->orX(
 					...array_map(function (string $email) use ($qb) {
-						return $qb->expr()->iLike('r0.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r2.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getCc()),
 					...array_map(function (string $label) use ($qb) {
-						return $qb->expr()->iLike('r0.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r2.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getCc()),
-				)
+				),
+				$qb->expr()->eq('r2.type', $qb->createNamedParameter(Recipient::TYPE_CC, IQueryBuilder::PARAM_INT)),
 			);
 		}
 		if (!empty($query->getBcc())) {
 			$select->andWhere(
 				$qb->expr()->orX(
 					...array_map(function (string $email) use ($qb) {
-						return $qb->expr()->iLike('r0.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r3.email', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($email) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getBcc()),
 					...array_map(function (string $label) use ($qb) {
-						return $qb->expr()->iLike('r0.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
+						return $qb->expr()->iLike('r3.label', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($label) . '%', IQueryBuilder::PARAM_STR));
 					}, $query->getBcc()),
-				)
+				),
+				$qb->expr()->eq('r3.type', $qb->createNamedParameter(Recipient::TYPE_BCC, IQueryBuilder::PARAM_INT)),
 			);
 		}
 
+		$textOrs = [];
 		if (!empty($query->getSubjects())) {
-			$select->andWhere(
-				$qb->expr()->orX(
-					...array_map(function (string $subject) use ($qb) {
-						return $qb->expr()->iLike(
-							'm.subject',
-							$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
-							IQueryBuilder::PARAM_STR
-						);
-					}, $query->getSubjects())
-				)
+			$textOrs[] = $qb->expr()->orX(
+				...array_map(function (string $subject) use ($qb) {
+					return $qb->expr()->iLike(
+						'm.subject',
+						$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
+						IQueryBuilder::PARAM_STR
+					);
+				}, $query->getSubjects())
 			);
 		}
+		// createParameter
+		if ($uids !== null) {
+			// In the case of body+subject search we need a combination of both results,
+			// thus the orWhere in every other case andWhere should do the job.
+			if(!empty($query->getSubjects())) {
+				$textOrs[] = $qb->expr()->in('m.uid', $qb->createParameter('uids'));
+			} else {
+				$select->andWhere(
+					$qb->expr()->in('m.uid', $qb->createParameter('uids'))
+				);
+			}
+		}
+		if (!empty($textOrs)) {
+			$select->andWhere($qb->expr()->orX(...$textOrs));
+		}
 
 		if (!empty($query->getStart())) {
 			$select->andWhere(
@@ -824,18 +843,16 @@ class MessageMapper extends QBMapper {
 			);
 		}
 
-		if ($query->getCursor() !== null) {
+		if ($query->getCursor() !== null && $sortOrder === IMailSearch::ORDER_NEWEST_FIRST) {
 			$select->andWhere(
 				$qb->expr()->lt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
 			);
-		}
-
-		// createParameter
-		if ($uids !== null) {
+		} elseif ($query->getCursor() !== null && $sortOrder === IMailSearch::ORDER_OLDEST_FIRST) {
 			$select->andWhere(
-				$qb->expr()->in('m.uid', $qb->createParameter('uids'))
+				$qb->expr()->gt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
 			);
 		}
+
 		foreach ($query->getFlags() as $flag) {
 			$select->andWhere($qb->expr()->eq('m.' . $this->flagToColumnName($flag), $qb->createNamedParameter($flag->isSet(), IQueryBuilder::PARAM_BOOL)));
 		}
@@ -849,7 +866,11 @@ class MessageMapper extends QBMapper {
 
 		$select->andWhere($qb->expr()->isNull('m2.id'));
 
-		$select->orderBy('m.sent_at', 'desc');
+		if ($sortOrder === 'ASC') {
+			$select->orderBy('sent_at', $sortOrder);
+		} else {
+			$select->orderBy('sent_at', 'DESC');
+		}
 
 		if ($limit !== null) {
 			$select->setMaxResults($limit);
@@ -864,9 +885,10 @@ class MessageMapper extends QBMapper {
 			}, array_chunk($uids, 1000));
 		}
 
-		return array_map(static function (Message $message) {
+		$result = array_map(static function (Message $message) {
 			return $message->getId();
 		}, $this->findEntities($select));
+		return $result;
 	}
 
 	public function findIdsGloballyByQuery(IUser $user, SearchQuery $query, ?int $limit, array $uids = null): array {
@@ -944,6 +966,18 @@ class MessageMapper extends QBMapper {
 			);
 		}
 
+		if (!empty($query->getStart())) {
+			$select->andWhere(
+				$qb->expr()->gte('m.sent_at', $qb->createNamedParameter($query->getStart()), IQueryBuilder::PARAM_INT)
+			);
+		}
+
+		if (!empty($query->getEnd())) {
+			$select->andWhere(
+				$qb->expr()->lte('m.sent_at', $qb->createNamedParameter($query->getEnd()), IQueryBuilder::PARAM_INT)
+			);
+		}
+
 		if ($query->getCursor() !== null) {
 			$select->andWhere(
 				$qb->expr()->lt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
@@ -1103,21 +1137,21 @@ class MessageMapper extends QBMapper {
 	/**
 	 * @param string $userId
 	 * @param int[] $ids
+	 * @param string $sortOrder
 	 *
 	 * @return Message[]
 	 */
-	public function findByIds(string $userId, array $ids): array {
+	public function findByIds(string $userId, array $ids, string $sortOrder): array {
 		if ($ids === []) {
 			return [];
 		}
-
 		$qb = $this->db->getQueryBuilder();
 		$qb->select('*')
 			->from($this->getTableName())
 			->where(
 				$qb->expr()->in('id', $qb->createParameter('ids'))
 			)
-			->orderBy('sent_at', 'desc');
+			->orderBy('sent_at', $sortOrder);
 
 		$results = [];
 		foreach (array_chunk($ids, 1000) as $chunk) {
@@ -1203,14 +1237,19 @@ class MessageMapper extends QBMapper {
 	/**
 	 * @param Mailbox $mailbox
 	 * @param array $ids
+	 * @param int|null $lastMessageTimestamp
+	 * @param IMailSearch::ORDER_* $sortOrder
+	 *
 	 * @return int[]
 	 */
-	public function findNewIds(Mailbox $mailbox, array $ids): array {
+	public function findNewIds(Mailbox $mailbox, array $ids, ?int $lastMessageTimestamp, string $sortOrder): array {
 		$select = $this->db->getQueryBuilder();
 		$subSelect = $this->db->getQueryBuilder();
 
 		$subSelect
-			->select($subSelect->func()->min('sent_at'))
+			->select($sortOrder === IMailSearch::ORDER_NEWEST_FIRST ?
+				$subSelect->func()->min('sent_at') :
+				$subSelect->func()->max('sent_at'))
 			->from($this->getTableName())
 			->where(
 				$subSelect->expr()->eq('mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
@@ -1222,20 +1261,31 @@ class MessageMapper extends QBMapper {
 		$selfJoin = $select->expr()->andX(
 			$select->expr()->eq('m.mailbox_id', 'm2.mailbox_id', IQueryBuilder::PARAM_INT),
 			$select->expr()->eq('m.thread_root_id', 'm2.thread_root_id', IQueryBuilder::PARAM_INT),
-			$select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT)
+			$sortOrder === IMailSearch::ORDER_NEWEST_FIRST ?
+				$select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT) :
+				$select->expr()->gt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT)
 		);
+		$wheres = [$select->expr()->eq('m.mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
+			$select->expr()->andX($subSelect->expr()->notIn('m.id', $select->createParameter('ids'), IQueryBuilder::PARAM_INT_ARRAY)),
+			$select->expr()->isNull('m2.id'),
+		];
+		if ($sortOrder === IMailSearch::ORDER_NEWEST_FIRST) {
+			$wheres[] = $select->expr()->gt('m.sent_at', $select->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT);
+		} else {
+			$wheres[] = $select->expr()->lt('m.sent_at', $select->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT);
+		}
+
+		if ($lastMessageTimestamp !== null && $sortOrder === IMailSearch::ORDER_OLDEST_FIRST) {
+			// Don't consider old "new messages" as new when their UID has already been seen before
+			$wheres[] = $select->expr()->lt('m.sent_at', $select->createNamedParameter($lastMessageTimestamp, IQueryBuilder::PARAM_INT));
+		}
 
 		$select
-			->select('m.id')
+			->select(['m.id', 'm.sent_at'])
 			->from($this->getTableName(), 'm')
 			->leftJoin('m', $this->getTableName(), 'm2', $selfJoin)
-			->where(
-				$select->expr()->eq('m.mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
-				$select->expr()->andX($subSelect->expr()->notIn('m.id', $select->createParameter('ids'), IQueryBuilder::PARAM_INT_ARRAY)),
-				$select->expr()->isNull('m2.id'),
-				$select->expr()->gt('m.sent_at', $select->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT)
-			)
-			->orderBy('m.sent_at', 'desc');
+			->where(...$wheres)
+			->orderBy('m.sent_at', $sortOrder === IMailSearch::ORDER_NEWEST_FIRST ? 'desc' : 'asc');
 
 		$results = [];
 		foreach (array_chunk($ids, 1000) as $chunk) {
