@@ -6,6 +6,7 @@ namespace OCA\Mail\Migration;
 
 use Closure;
 use OCP\DB\ISchemaWrapper;
+use OCP\DB\Types;
 use OCP\IDBConnection;
 use OCP\Migration\IOutput;
 use OCP\Migration\SimpleMigrationStep;
@@ -29,7 +30,7 @@ class Version2010Date20221002201527 extends SimpleMigrationStep {
 		$schema = $schemaClosure();
 
 		$accountsTable = $schema->getTable('mail_accounts');
-		$accountsTable->addColumn('archive_mailbox_id', 'integer', [
+		$accountsTable->addColumn('archive_mailbox_id', Types::INTEGER, [
 			'notnull' => false,
 			'default' => null,
 			'length' => 20,
@@ -46,6 +47,6 @@ class Version2010Date20221002201527 extends SimpleMigrationStep {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('mail_accounts')
 			->set('last_mailbox_sync', $update->createNamedParameter(0));
-		$update->execute();
+		$update->executeStatement();
 	}
 }
