@@ -33,6 +33,7 @@ use OCA\Mail\Db\MailAccount;
 use OCA\Mail\Db\MailAccountMapper;
 use OCA\Mail\Exception\ClientException;
 use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\IMAP\IMAPClientFactory;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\BackgroundJob\IJobList;
 use function array_map;
@@ -54,12 +55,17 @@ class AccountService {
 	/** @var IJobList */
 	private $jobList;
 
+	/** @var IMAPClientFactory*/
+	private $imapClientFactory;
+
 	public function __construct(MailAccountMapper $mapper,
 		AliasesService $aliasesService,
-		IJobList $jobList) {
+		IJobList $jobList,
+		IMAPClientFactory $imapClientFactory) {
 		$this->mapper = $mapper;
 		$this->aliasesService = $aliasesService;
 		$this->jobList = $jobList;
+		$this->imapClientFactory = $imapClientFactory;
 	}
 
 	/**
@@ -181,4 +187,22 @@ class AccountService {
 	public function getAllAcounts(): array {
 		return $this->mapper->getAllAccounts();
 	}
+
+	
+	/**
+	 * @param string $currentUserId
+	 * @param int $accountId
+	 * @return bool
+	 */
+
+	public function testAccountConnection(string $currentUserId, int $accountId) :bool {
+		$account = $this->find($currentUserId, $accountId);
+		try {
+			$client = $this->imapClientFactory->getClient($account);
+			$client->close();
+			return true;
+		} catch (\Throwable $e) {
+			return false;
+		}
+	}
 }
